==> packagekit_0.7.6.orig.tar.xz: PackageKit-0.7.6/backends/alpm/pk-backend-databases.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2007 Andreas Obergrusberger <tradiaz@yahoo.de>
 * Copyright (C) 2008-2010 Valeriy Lyasotskiy <onestep@ukr.net>
 * Copyright (C) 2010-2011 Jonathan Conder <jonno.conder@gmail.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <alpm.h>
#include <pk-backend.h>

void		 pk_backend_configure_repos		(alpm_list_t *repos,
							 GHashTable *servers,
							 GHashTable *levels);

gboolean	 pk_backend_disable_signatures		(PkBackend *self,
							 GError **error);

gboolean	 pk_backend_enable_signatures		(PkBackend *self,
							 GError **error);

gboolean	 pk_backend_initialize_databases	(PkBackend *self,
							 GError **error);

void		 pk_backend_destroy_databases		(PkBackend *self);

==> packagekit_0.8.17.orig.tar.xz: PackageKit-0.8.17/backends/alpm/pk-backend-databases.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2007 Andreas Obergrusberger <tradiaz@yahoo.de>
 * Copyright (C) 2008-2010 Valeriy Lyasotskiy <onestep@ukr.net>
 * Copyright (C) 2010-2011 Jonathan Conder <jonno.conder@gmail.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <alpm.h>
#include <pk-backend.h>

void		 pk_backend_add_database		(const gchar *name,
							 alpm_list_t *servers,
							 alpm_siglevel_t level);

gboolean	 pk_backend_disable_signatures		(PkBackend *self,
							 GError **error);

gboolean	 pk_backend_enable_signatures		(PkBackend *self,
							 GError **error);

gboolean	 pk_backend_initialize_databases	(PkBackend *self,
							 GError **error);

void		 pk_backend_destroy_databases		(PkBackend *self);
